/**
 * Evaluates whether a string is a DNS compatible bucket name and can be used with
 * virtual hosted style addressing.
 */
export declare const isVirtualHostableS3Bucket: (value: string, allowSubDomains?: boolean) => boolean;
