import { EndpointARN } from "@smithy/types";
/**
 * Evaluates a single string argument value, and returns an object containing
 * details about the parsed ARN.
 * If the input was not a valid ARN, the function returns null.
 */
export declare const parseArn: (value: string) => EndpointARN | null;
